<?php

/*-----------------------------------------------------------------------------------*/
/* Enqueu scripts */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('intenso_enqueue_scripts')) {

	function intenso_enqueue_scripts() {

		wp_deregister_style( 'avventura-lite-style' );
		wp_deregister_style( 'avventura-lite-' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')) );

		wp_enqueue_style( 'avventura-lite-parent-style' , get_template_directory_uri() . '/style.css' ); 

		wp_enqueue_style(
			'intenso-' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')),
			get_stylesheet_directory_uri() . '/assets/skins/' . esc_attr(get_theme_mod('avventura_lite_skin', 'orange')) . '.css',
			array( 'intenso-style' ),
			'1.0.0'
		); 

		wp_enqueue_style( 'intenso-style' , get_stylesheet_directory_uri() . '/style.css' ); 

		$googleFontsArgs = array(
			'family' =>	str_replace('|', '%7C','Poppins:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i'),
			'subset' =>	'latin,latin-ext'
		);
		
		wp_deregister_style('google-fonts');
		wp_enqueue_style('google-fonts', add_query_arg ( $googleFontsArgs, "https://fonts.googleapis.com/css" ), array(), '1.0.0' );

	}
	
	add_action( 'wp_enqueue_scripts', 'intenso_enqueue_scripts', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Replace hooks */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('intenso_replace_hooks')) {

	function intenso_replace_hooks() {
		remove_action('avventura_lite_slick_slider', 'avventura_lite_slick_slider_function');
		remove_action('avventura_lite_top_sidebar', 'avventura_lite_top_sidebar_function');
		remove_action('avventura_lite_thumbnail', 'avventura_lite_thumbnail_function');
	}
	
	add_action('init','intenso_replace_hooks');

}

/*-----------------------------------------------------------------------------------*/
/* Exclude sticky posts on home */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('intenso_exclude_sticky_posts_on_home')) {

	function intenso_exclude_sticky_posts_on_home($query) {
		
		if ( 
			$query->is_home() && 
			$query->is_main_query() && 
			(!avventura_lite_setting('intenso_sticky_posts') || strstr(avventura_lite_setting('intenso_sticky_posts'), 'layout' ))) {
			$query->set('post__not_in', get_option( 'sticky_posts' ));
		}
	
	}
	
	add_action('pre_get_posts', 'intenso_exclude_sticky_posts_on_home');

}

/*-----------------------------------------------------------------------------------*/
/* Sticky post grid */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('intenso_sticky_posts_function')) {

	function intenso_sticky_posts_function() {

		$isHome = ( !avventura_lite_setting('intenso_sticky_posts') || strstr(avventura_lite_setting('intenso_sticky_posts'), 'layout' )) ? TRUE : FALSE;
		$isSlideshow = ( $isHome == TRUE && ( is_home() || is_front_page()) ) ? TRUE : FALSE;
		
		$args = array(
			'post_type' => 'post',
			'posts_per_page' => 3,
			'post__in'  => get_option( 'sticky_posts' ),
			'ignore_sticky_posts' => 1,
			'meta_query' => 
			array(
				array(
					'key' => '_thumbnail_id',
					'compare' => 'EXISTS'
				)
			)
		);

		$query = new WP_Query($args); 

		if ( 
			$isSlideshow && 
			$query->have_posts() 
		) : 

	?>
		
        <section class="sticky-posts-main-wrapper">
        
            <div id="sticky-posts-container" class="container">
                
                <div class="row">
                    
                    <div class="col-md-12">
                        
                        <div class="sticky-posts-wrapper <?php echo esc_attr(avventura_lite_setting('intenso_sticky_posts','layout-1'));?>">
            
							<?php
        
                                while ( $query->have_posts() ) : $query->the_post(); 
                
                                    global $post;
                                    $thumb = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large');
        
                            ?>
    
                                <div class="sticky-post sticky-post-<?php echo $query->current_post?>" style="background-image: url(<?php echo esc_url($thumb[0]); ?>);" >
                                
                                    <a title="<?php echo esc_attr(get_the_title());?>" class="sticky-post-permalink" href="<?php echo esc_url(get_permalink($post->ID)); ?>" ></a>
                        
                                    <h2 class="title"><?php echo esc_html(get_the_title()); ?></h2>
                                    
                                    <?php 
                                        
                                        $categories = get_the_category();
                                        
                                        if ( !empty( $categories ) ) {
                                            
                                            echo '<div class="sticky-post-categories">';
    
                                            foreach ( $categories as $category ) {
                                                echo '<div class="sticky-post-category">' . esc_html($category->name) . '</div>';
                                            }
                                            
                                            echo '</div>';
    
                                        }
    
                                    ?>
                
                                </div>
                
							<?php
    
                                endwhile; 
                                wp_reset_postdata();
    
                            ?>
    
							<div class="clear"></div>
    
                        </div>        
    
                    </div>        
    
                </div>    
    
            </div>        
                    
    	</section>
        
	<?php 
	
		endif;
		
	}

	add_action( 'intenso_sticky_posts', 'intenso_sticky_posts_function');

}

/*-----------------------------------------------------------------------------------*/
/* Top sidebar */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('intenso_top_sidebar_function')) {

	function intenso_top_sidebar_function() {

		$isWidget = is_active_sidebar('avventura-lite-top-widget-area') ? TRUE : FALSE;

		if ( $isWidget ) : 
	
	?>
			
			<div id="top_sidebar" class="sidebar-area">
			
				<?php 
							
					if ( $isWidget == TRUE )
						dynamic_sidebar('avventura-lite-top-widget-area');
                    	
				?>
                			
			</div>
				
	<?php 
	
		endif;
		
	}

	add_action( 'avventura_lite_top_sidebar', 'intenso_top_sidebar_function' );

}


/*-----------------------------------------------------------------------------------*/
/* Customize register */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('intenso_customize_register')) {

	function intenso_customize_register( $wp_customize ) {

		$wp_customize->remove_control( 'avventura_lite_header_layout');
		$wp_customize->remove_section( 'slideshow_section');
		$wp_customize->remove_control( 'avventura_lite_post_icon');
		
		$wp_customize->add_control( 'avventura_lite_post_icon' , array(
			'type' => 'select',
			'section' => 'settings_section',
			'label' => esc_html__('Post Icon', 'intenso'),
			'description' => esc_html__('Do you want to display the post icon?', 'intenso'),
			'choices'  => array (
				'off' => esc_html__( 'No',   'intenso'),
				'on' => esc_html__( 'Yes', 'intenso'),
			),
		));

		$wp_customize->add_setting( 'intenso_sticky_posts', array(
			'default' => 'layout-1',
			'sanitize_callback' => 'intenso_select_sanitize',

		));

		$wp_customize->add_control( 'intenso_sticky_posts' , array(
			'type' => 'select',
			'priority' => '09',
			'section' => 'settings_section',
			'label' => esc_html__('Sticky post grid','intenso'),
			'description' => esc_html__('Do you want to enable the sticky post grid on homepage? (Set at least a post as sticky post to filter the articles)','intenso'),
			'choices'  => array (
			   'disable' => esc_html__( 'Disable','intenso'),
			   'layout-1' => esc_html__( 'Layout 1','intenso'),
			   'layout-2' => esc_html__( 'Layout 2','intenso'),
			   'layout-3' => esc_html__( 'Layout 3','intenso'),
			   'layout-4' => esc_html__( 'Layout 4','intenso'),
			),
		));
		
		function intenso_select_sanitize ($value, $setting) {
		
			global $wp_customize;
					
			$control = $wp_customize->get_control( $setting->id );
				 
			if ( array_key_exists( $value, $control->choices ) ) {
					
				return $value;
					
			} else {
					
				return $setting->default;
					
			}
			
		}
		
	}
	
	add_action( 'customize_register', 'intenso_customize_register', 11 );

}

/*-----------------------------------------------------------------------------------*/
/* Theme setup */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('intenso_theme_setup')) {

	function intenso_theme_setup() {

		load_child_theme_textdomain( 'intenso', get_stylesheet_directory() . '/languages' );
		
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/functions/function-style.php' );

		remove_theme_support('custom-logo');
		
		add_theme_support( 'custom-logo', array( 'header-text' => array( 'site-title', 'site-description' )) );
		
		add_theme_support( 'custom-background', array( 'default-color' => '#e5e5e5') );

		register_default_headers( array(
			'default-image' => array(
				'url'           => get_stylesheet_directory_uri() . '/assets/images/header/header.jpg',
				'thumbnail_url' => get_stylesheet_directory_uri() . '/assets/images/header/resized-header.jpg',
				'description'   => esc_html__( 'Default image', 'intenso' )
			),
		));

		add_theme_support( 'custom-header', array( 
			'width'         => 1920,
			'height'        => 600,
			'default-image' => get_stylesheet_directory_uri() . '/assets/images/header/header.jpg',
			'header-text' 	=> false
		));

	}

	add_action( 'after_setup_theme', 'intenso_theme_setup', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Featured image */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('intenso_thumbnail_function')) {

	function intenso_thumbnail_function($id, $icon = 'on') {

		global $post;
		
		if ( '' != get_the_post_thumbnail() ) { 
			
	?>
			
			<div class="pin-container">
					
				<?php 
						
					the_post_thumbnail($id);

					if ( $icon == 'on' ):
							
						echo avventura_lite_posticon();	
							
					endif;

				?>
                    
			</div>
			
	<?php
	
		}
	
	}

	add_action( 'avventura_lite_thumbnail', 'intenso_thumbnail_function', 10, 2 );

}

?>